| Title: | Automated Affymetrix Array Analysis Preprocessing Package |
|---|---|
| Description: | Utility functions to pre-process data for the Automated Affymetrix Array Analysis set of packages. |
| Authors: | Willem Talloen [aut], Tobias Verbeke [aut], Laure Cougnaud [cre] |
| Maintainer: | Laure Cougnaud <[email protected]> |
| License: | GPL-3 |
| Version: | 1.61.0 |
| Built: | 2026-05-29 08:49:34 UTC |
| Source: | https://github.com/bioc/a4Preproc |
Adds appropriate featureData, similar to the metadata added in the pipeline script, to the ExpressionSet object.
addGeneInfo(eset, annotationLibrary = NULL)addGeneInfo(eset, annotationLibrary = NULL)
eset |
ExpressionSet object for to which one wants to add additional annotation information |
annotationLibrary |
Annotation Library to use. Must be specified when working with Entrez gene IDs.
In this case, one can make use of the JnJ annotation packages such as |
Slots of featureData(a4ALL) are
Entrez ID~: Entrez ID as retrieved from annotation package
Ensembl ID~: Ensembl ID as retrieved from annotation package
Gene Symbol~: Gene symbol as retrieved from annotation package
Description~: Description as retrieved from annotation package
a new ExpressionSet object with the additional information stored as feature data
One should always use subscripting of featureData by column name
(e.g. featureData(a4ALL)$`Entrez ID`; as the pipeline
ExpressionSets have one additional column compared to the ExpressionSet
objects produced by addGeneInfo, i.e. column 2 of the pipeline ExpressionSets
corresponds to column one of an addGeneInfo ExpressionSet.
Tobias Verbeke, Steven Osselaer
library(ALL) data(ALL) a4ALL <- addGeneInfo(ALL) head(featureData(a4ALL)$`Entrez ID`)library(ALL) data(ALL) a4ALL <- addGeneInfo(ALL) head(featureData(a4ALL)$`Entrez ID`)